<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'Compagnon ponúka pomoc používateľom 
		pri ich prvej návšteve v súkromnej zóne SPIPu.',
	'compagnon_nom' => 'Compagnon',
	'compagnon_slogan' => 'Sprievodca pri prvých krokoch so SPIPom',
];
